@@ -22,7 +22,7 @@
 
 #define CHAR_WIDTH 5
 #define CHAR_HEIGHT 7
-#define VERSION "2.9"
+#define VERSION "2.91"
 #define _MULTI_THREADED
 
 typedef enum {NONE, ALARM, TIMER, TIMER_PAUSED, TIMER_DONE, CHRONO, CHRONO_PAUSED} modeType;
@@ -734,8 +734,6 @@ void *configure(void *arg)
   spinner1 = gtk_spin_button_new (adj, 0, 0);
   gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spinner1), TRUE);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinner1), TRUE);
-  gtk_spin_button_set_shadow_type (GTK_SPIN_BUTTON (spinner1),
-      GTK_SHADOW_OUT);
   gtk_box_pack_start (GTK_BOX (box2), spinner1, FALSE, FALSE, 2);
   gtk_widget_show (spinner1);
 
@@ -750,8 +748,6 @@ void *configure(void *arg)
   spinner2 = gtk_spin_button_new (adj, 0, 0);
   gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spinner2), TRUE);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinner2), TRUE);
-  gtk_spin_button_set_shadow_type (GTK_SPIN_BUTTON (spinner2),
-      GTK_SHADOW_OUT);
   gtk_box_pack_start (GTK_BOX (box2), spinner2, FALSE, FALSE, 2);
   gtk_widget_show (spinner2);
 
@@ -766,7 +762,6 @@ void *configure(void *arg)
   spinner3 = gtk_spin_button_new (adj, 0, 0);
   gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spinner3), TRUE);
   gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinner3), TRUE);
-  gtk_spin_button_set_shadow_type (GTK_SPIN_BUTTON (spinner3), GTK_SHADOW_OUT);
   gtk_box_pack_start (GTK_BOX (box2), spinner3, FALSE, FALSE, 2);
   gtk_widget_show (spinner3);
   gtk_widget_show (box2);
